# Об ONGX

ONGX - это движок для создание двухмерных игр а также трехмерных игр

# кем он создан?

ОNGX делан командой "одним человеком" с название ЧВК "DRAGON"

![описание](main/assets/icon.png)


# ФУНКЦИИ ДВИЖКА

| ФУНКЦИИ       | ЗАЧЕМ | ЗАНЧЕНИЕ |
|---------------|-------|----------|
 | clear.color() | ИЗМЕНЕНИЕ ЦВЕТА| там должно быть RGB |

# ПРИМЕР КОДА

### установка
``` shell 
pip install ongx
```

### использование

``` python

import ongx as ng

app = ng.App()

app.run
```

## Удачи!  


 © 2026 ONGX
